"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.arrayLength = exports.arrayUniqueObjects = exports.arrayUnique = exports.array = void 0;
// This file is the perfect example of when to place multiple rules in same file.
// All rules in this file have common check ie. isArray and on top of that 
// 2 of them have unique check.
/**
 * The field under validation must be array.
 */
function array() {
    return {
        name: "array",
        handler: (value) => {
            return Array.isArray(value);
        },
    };
}
exports.array = array;
/**
 * The field under validation must be array of unique values.
 * No need to use array rule. This rule will take care of that.
 */
function arrayUnique() {
    return {
        name: "arrayUnique",
        handler: (value) => {
            if (!Array.isArray(value)) {
                return false;
            }
            return (new Set(value)).size === value.length;
        },
    };
}
exports.arrayUnique = arrayUnique;
/**
 * The field under validation must be array and should have objects with unique attributes as per seed.
 * No need to use array rule. This rule will take care of that.
 * @param args seeds
 */
function arrayUniqueObjects(args) {
    return {
        name: "arrayUniqueObjects",
        handler: (value) => {
            if (!Array.isArray(value)) {
                return false;
            }
            const result = new Set(value.map((o) => {
                let output = "";
                for (const attr of args) {
                    output += o[attr];
                }
                return output;
            }));
            return result.size === value.length;
        },
    };
}
exports.arrayUniqueObjects = arrayUniqueObjects;
/**
 * @since: v5
 * The field under validation must be array of length as per seed.
 * @param args seeds
 */
function arrayLength(args) {
    if (args.length !== 1) {
        throw new Error('Invalid number of arguments.');
    }
    const len = parseInt(args[0], 10);
    return {
        name: "array",
        handler: (value) => {
            return (Array.isArray(value) && value.length === len);
        },
    };
}
exports.arrayLength = arrayLength;
//# sourceMappingURL=array.rule.js.map